;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "swagg" "20250913.1822"
  "Swagger UI."
  '((emacs   "27.1")
    (compat  "29.1.4.0")
    (request "0.3.3")
    (dash    "2.19.1")
    (yaml    "0.5.1")
    (s       "1.13.1"))
  :url "https://github.com/isamert/swagg.el"
  :commit "1fe1acf42cd7fe7ffbb56b82a030a53e544b8ff6"
  :revdesc "1fe1acf42cd7"
  :keywords '("tools" "convenience")
  :authors '(("Isa Mert Gurbuz" . "isamertgurbuz@gmail.com"))
  :maintainers '(("Isa Mert Gurbuz" . "isamertgurbuz@gmail.com")))
